/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:EasyBeansManagedRuntime.java 1477 2007-06-16 16:50:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.assemblies.tomcat.test;

import net.sourceforge.jwebunit.junit.WebTester;

import org.testng.Assert;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

/**
 * Test the Tomcat assembly.
 * @author Florent Benoit
 */
public class TomcatTest {

    /**
     * Tester object.
     */
    private WebTester webTester;

    /**
     * Initialize the test framework.
     * @throws Exception if the framework is not initalized.
     */
    @BeforeClass
    protected void init() throws Exception {

        // Build tester object
        this.webTester = new WebTester();

        // Get the http port property
        String httpPort = System.getProperty("http.port");

        if (httpPort == null) {
            throw new Exception("Cannot get the http.port system property");
        }

        this.webTester.getTestContext().setBaseUrl("http://localhost:" + httpPort + "/");
    }

    /**
     * Check that the EasyBeans war is available (and then deployed).
     * @throws Exception if EasyBeans is not available
     */
    @Test
    public void easyBeansAvailable() throws Exception {
        this.webTester.beginAt("/ow2-easybeans");
        Assert.assertTrue(this.webTester.getPageSource().contains("EasyBeans"));
    }

    /**
     * Test if the EAR example is working.
     */
    @Test(dependsOnMethods = "easyBeansAvailable")
    public void testEarWebSample() {
        this.webTester.beginAt("/ear-web");

        // Get content
        String pageContent = this.webTester.getPageSource();

        // Check if authors Victor Hugo & Balzac are present
        if (!pageContent.contains("Honore de Balzac") || !pageContent.contains("Victor Hugo")) {
            Assert.fail("Page '" + pageContent + "' does not contain the authors !");
        }

        // Some books available too ?
        if (!pageContent.contains("Les Chouans") ||  !pageContent.contains("Les Miserables")) {
            Assert.fail("Page '" + pageContent + "' does not contain the books !");
        }

    }

    /**
     * Test if the maven EAR example is working.
     */
    @Test(dependsOnMethods = "easyBeansAvailable")
    public void testMavenEarWebSample() {
        this.webTester.beginAt("/example-webapp/sayHello");

        // Get content
        String pageContent = this.webTester.getPageSource();

        // Check if Hello string is present
        if (!pageContent.contains("Hello")) {
            Assert.fail("Page '" + pageContent + "' does not contain hello !");
        }

        /*
        if (!pageContent.contains("library")) {
            Assert.fail("Page '" + pageContent + "' does not contain library !");
        }
        */



    }



}
